View source: R/bivariate_response.R
| bivariate_response | R Documentation |
A plot of suitability prediction in a two-dimensional environmental space.
bivariate_response(models, variable1 , variable2, modelID = NULL, n = 500,
new_data = NULL, extrapolate = TRUE, add_bar = TRUE ,
add_limits = TRUE, color_palette = NULL,
xlab = NULL, ylab = NULL, ...)
models |
an object of class |
variable1 |
(character) name of the variable to be plotted in x axis. |
variable2 |
(character) name of the variable to be plotted in y axis. |
modelID |
(character) name of the ModelID presents in the fitted object. Default = NULL. |
n |
(numeric) the number of breaks for plotting grid. Default = 500 |
new_data |
a |
extrapolate |
(logical) whether to allow extrapolation to study the
behavior of the response outside the calibration limits. Ignored if
|
add_bar |
(logical) whether to add bar legend. Default = TRUE. |
add_limits |
(logical) whether to add calibration limits if
|
color_palette |
(function) a color palette function to be used to assign
colors in the plot. The default, NULL uses |
xlab |
(character) a label for the x axis. The default, NULL, uses the
name defined in |
ylab |
(character) a label for the y axis. The default, NULL, uses the
name defined in |
... |
additional arguments passed to |
A bivariate plot considering variable1 and variable2.
response_curve()
# Example with glmnet
# Import example of fitted_models (output of fit_selected())
data(fitted_model_maxnet, package = "kuenm2")
# Response curve (notice response affected by covariance)
bivariate_response(models = fitted_model_maxnet, modelID = "Model_219",
variable1 = "bio_1", variable2 = "bio_12")
# Example with glm
# Import example of fitted_models (output of fit_selected())
data(fitted_model_glm, package = "kuenm2")
# Response curve
bivariate_response(models = fitted_model_glm, modelID = "Model_85",
variable1 = "bio_1", variable2 = "bio_7")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.