| calib_results_maxnet | R Documentation |
A calibration_results object resulted from calibration() using maxnet algorithm
data("calib_results_maxnet")
A calibration_results with the following elements:
Species names
A data.frame with the variables extracted to presence and background points
A data.frame with the ID, formulas, and regularization multipliers of each candidate model
A list with the partition data, where each element corresponds to a replicate and contains the indices of the test points for that replicate
A character indicating the partition method
A numeric value indicating the number of replicates or k-folds
A numeric value indicating the proportion of occurrences used as train points when the partition method is 'subsample' or 'bootstrap'
A data.frame with the coordinates of the occurrence and background points
A character indicating the names of the continuous variables
A character indicating the names of the categorical variables
A numeric value specifying weights for the occurrence records. It's NULL, meaning it was not set weights.
A prcomp object storing PCA information. Is NULL, meaning PCA was not performed
A character indicating the algorithm (maxnet)
A list containing the evaluation metrics for each candidate model
A numeric value indicating the omission rate used to evaluate the models (10%)
A logical value indicating whether to add to the background any presence sample that is not already there.
A data.frame with the formulas and evaluation metrics for each selected model
A list with the number and the ID of the models removed and selected during selection procedure
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.