chelsa_lgm_miroc: SpatRaster Representing LGM Conditions (GCM: MIROC-ESM)

chelsa_lgm_mirocR Documentation

SpatRaster Representing LGM Conditions (GCM: MIROC-ESM)

Description

Raster layer containing bioclimatic variables representing Last Glacial Maximum (LGM) climatic conditions based on the MIROC-ESM General Circulation Model. The variables were resampled to 10arc-minutes and masked using the m provided in the package.

Format

A SpatRaster object.

Value

No return value. Used with function rast to bring raster variables to analysis.

Examples

chelsa_lgm_miroc <- terra::rast(system.file("extdata",
                                           "CHELSA_LGM_MIROC-ESM.tif",
                                           package = "kuenm2"))
terra::plot(chelsa_lgm_miroc)

kuenm2 documentation built on April 21, 2026, 1:07 a.m.