chelsa_lgm_mpi: SpatRaster Representing LGM Conditions (GCM: MPI-ESM-P)

chelsa_lgm_mpiR Documentation

SpatRaster Representing LGM Conditions (GCM: MPI-ESM-P)

Description

Raster layer containing bioclimatic variables representing Last Glacial Maximum (LGM) climatic conditions based on the MPI-ESM-P General Circulation Model. The variables were resampled to 10arc-minutes and masked using the m provided in the package.

Format

A SpatRaster object.

Value

No return value. Used with function rast to bring raster variables to analysis.

Examples

chelsa_lgm_mpi <- terra::rast(system.file("extdata",
                                           "CHELSA_LGM_MPI-ESM-P.tif",
                                           package = "kuenm2"))
terra::plot(chelsa_lgm_mpi)

kuenm2 documentation built on April 21, 2026, 1:07 a.m.