| enmeval_block | R Documentation |
A list resulting from ENMeval::get.block() to partition occurrence and background localities into bins for training and validation (or, evaluation and calibration). This object is used in the "Prepare Data for Model Calibration" vignette to demonstrate how to implement custom data partitions generated by ENMeval in kuenm2.
data("enmeval_block")
A list with the following elements:
A numeric vector indicating the spatial group to which each occurrence belongs
A numeric vector indicating the spatial group to which each background point belongs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.