| fitted_model_chelsa | R Documentation |
A fitted_models object resulting from fit_selected() using calibration data based on CHELSA variables.
data("fitted_model_chelsa")
A fitted_models with the following elements:
Species names
A list with the fitted maxnet models (replicates and full models)
A data.frame containing the variables extracted for presence and background points
A character indicating the names of the continuous variables
A character indicating the names of the categorical variables
A data.frame with formulas and evaluation metrics for each selected model
A numeric vector specifying weights for the occurrence records. NULL if no weights were set.
A prcomp object containing PCA results. NULL if PCA was not performed.
A logical value indicating whether to add any presence point not already included to the background.
A numeric value indicating the omission rate used to evaluate models.
A numeric vector with thresholds used to binarize each replicate and the consensus (mean and median), calculated based on the omission rate defined in calibration().
A character string indicating the algorithm used (maxnet).
A character string indicating the partitioning method used.
A numeric value indicating the number of replicates or folds.
A numeric value indicating the proportion of occurrences used for training when the partition method is 'subsample' or 'bootstrap'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.