A maxnet fitted_models object resulting from fit_selected() using calibration data with based on WorldClim variables.
Usage
data("fitted_model_maxnet")Format
A fitted_models with the following elements:
- species
Species names
- Models
A
listwith the fitted maxnet models (replicates and full models)- calibration_data
A
data.framecontaining the variables extracted for presence and background points- continuous_variables
A
characterindicating the names of the continuous variables- categorical_variables
A
characterindicating the names of the categorical variables- selected_models
A
data.framewith formulas and evaluation metrics for each selected model- weights
A
numericvector specifying weights for the occurrence records.NULLif no weights were set.- pca
A
prcompobject containing PCA results.NULLif PCA was not performed.- addsamplestobackground
A
logicalvalue indicating whether to add any presence point not already included to the background.- omission_rate
A
numericvalue indicating the omission rate used to evaluate models.- thresholds
A
numericvector with thresholds used to binarize each replicate and the consensus (mean and median), calculated based on the omission rate defined incalibration().- algorithm
A
characterstring indicating the algorithm used (maxnet).- partition_method
A
characterstring indicating the partitioning method used.- n_replicates
A
numericvalue indicating the number of replicates or folds.- train_proportion
A
numericvalue indicating the proportion of occurrences used for training when the partition method is 'subsample' or 'bootstrap'.