| flexsdm_block | R Documentation |
A list resulting from flexsdm::part_sblock(), used to partition occurrence and background localities into bins for training and evaluation. This object is used in the "Prepare Data for Model Calibration" vignette to demonstrate how to implement custom data partitions generated by flexsdm in kuenm2
data("enmeval_block")
A list with the following elements:
A tibble object with information used in 'data' arguments and a additional column .part with partition group.
A tibble with information about the best partition.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.