| future_2100_ssp585_miroc | R Documentation |
A raster layer containing bioclimatic variables representing future climatic
conditions (2081-2100) based on the MIROC6 General Circulation Model
under the SSP585 scenario. The variables were obtained at a 10 arc-minute
resolution and masked using the m region provided in the package. Data
sourced from WorldClim: https://worldclim.org/data/cmip6/cmip6climate.html
A SpatRaster object.
No return value. Used with function rast to
bring raster variables to analysis.
future_2100_ssp585_miroc <- terra::rast(system.file("extdata",
"wc2.1_10m_bioc_MIROC6_ssp585_2081-2100.tif",
package = "kuenm2"))
terra::plot(future_2100_ssp585_miroc)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.