m: SpatVector Representing Calibration Area for _Myrcia...

mR Documentation

SpatVector Representing Calibration Area for Myrcia hatschbachii

Description

A spatial vector defining the calibration area used to extract background points for fitting models of Myrcia hatschbachii. The area was generated by creating a minimum convex polygon around presence records (occ_data), then applying a 300 km buffer.

Format

A SpatVector object.

Value

No return value. Used with function vect to bring raster variables to analysis.

Examples

m <- terra::vect(system.file("extdata",
                             "m.gpkg",
                              package = "kuenm2"))
terra::plot(m)

kuenm2 documentation built on April 21, 2026, 1:07 a.m.