| new_occ | R Documentation |
A data.frame containing the coordinates of 82 occurrences of Myrcia hatschbachii (a tree endemic to southern Brazil). The valid occurrences were
sourced from NeotropicTree (Oliveira-Filho, 2017) and were used as
independent data to test the models fitted with the occ_data.
data("new_occ")
A data.frame with the following columns:
The species name.
Longitude.
Latitude.
Oliveira_Filho, A.T. 2017. NeoTropTree, Flora arbórea da Região Neotropical: Um banco de dados envolvendo biogeografia, diversidade e conservação. Universidade Federal de Minas Gerais. (http://www.neotroptree,info).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.