A prepared_data object resulted from prepare_data() to calibrate models using 'glm' algorithm.
Usage
data("sp_swd")Format
A prepared_data object with the following elements:
- species
Species names
- calibration_data
A
data.framecontaining the variables extracted for presence and background points- formula_grid
A
data.framewith the ID, formulas, and regularization multipliers of each candidate model- part_data
A
listwith the partition data, where each element corresponds to a replicate and contains the indices of the test points for that replicate- partition_method
A
characterindicating the partition method- n_replicates
A
numericvalue indicating the number of replicates or k-folds- train_proportion
A
numericvalue indicating the proportion of occurrences used as train points when the partition method is 'subsample' or 'bootstrap'- data_xy
A
data.framewith the coordinates of the occurrence and background points- continuous_variables
A
characterindicating the names of the continuous variables- categorical_variables
A
characterindicating the names of the categorical variables- weights
A
numericvalue specifying weights for the occurrence records. It's NULL, meaning it was not set weights.- pca
A
prcompobject storing PCA information. Is NULL, meaning PCA was not performed- algorithm
A
characterindicating the algorithm (glm)