| sp_swd_glm | R Documentation |
A prepared_data object resulted from prepare_data() to calibrate models using 'glm' algorithm.
data("sp_swd_glm")
A prepared_data object with the following elements:
Species names
A data.frame containing the variables extracted for presence and background points
A data.frame with the ID, formulas, and regularization multipliers of each candidate model
A list with the partition data, where each element corresponds to a replicate and contains the indices of the test points for that replicate
A character indicating the partition method
A numeric value indicating the number of replicates or k-folds
A numeric value indicating the proportion of occurrences used as train points when the partition method is 'subsample' or 'bootstrap'
A data.frame with the coordinates of the occurrence and background points
A character indicating the names of the continuous variables
A character indicating the names of the categorical variables
A numeric value specifying weights for the occurrence records. It's NULL, meaning it was not set weights.
A prcomp object storing PCA information. Is NULL, meaning PCA was not performed
A character indicating the algorithm (glm)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.