| user_data | R Documentation |
A data.frame containing presence and background records along with environmental variables used to demonstrate data preparation with user-supplied data.
data("user_data")
A data.frame with the following columns:
Column indicating presences (1) and background (0).
The extracted values for the variable bio_1 at presence and background points.
The extracted values for the variable bio_12 at presence and background points.
The extracted values for the variable bio_12 at presence and background points.
The extracted values for the variable bio_15 at presence and background points.
The extracted values for the variable soilType at presence and background points.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.