| glm_mx | R Documentation |
This function fits a Generalized Linear Model (GLM) to binary presence-background data. It allows for the specification of custom weights, with a default in which presences have a weight of 1 and background 100.
glm_mx(formula, family = binomial(link = "cloglog"), data,
weights = NULL, ...)
formula |
A formula specifying the model to be fitted, in the format
used by |
family |
A description of the error distribution and link function to be
used in the model. Defaults to |
data |
A |
weights |
Optional. A numeric vector of weights for each observation. If not provided, default weights of 1 for presences and 100 for background are used. |
... |
Additional arguments to be passed to |
For more details about glms using presence and background emulating what Maxent does, see Fithian and Hastie (2013) doi:10.1214/13-AOAS667.
A fitted glm object. The model object includes
the minimum and maximum values of the non-factor variables in the
dataset, stored as model$varmin and model$varmax.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.