| m | R Documentation |
A spatial vector defining the calibration area used to extract background
points for fitting models of Myrcia hatschbachii. The area was generated by
creating a minimum convex polygon around presence records (occ_data), then
applying a 300 km buffer.
A SpatVector object.
No return value. Used with function vect to
bring raster variables to analysis.
m <- terra::vect(system.file("extdata",
"m.gpkg",
package = "kuenm2"))
terra::plot(m)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.