| plot_importance | R Documentation |
See details in plot_importance
plot_importance(x, xlab = NULL, ylab = "Relative contribution",
main = "Variable importance", extra_info = TRUE, ...)
x |
data.frame output from |
xlab |
(character) a label for the x axis. |
ylab |
(character) a label for the y axis. |
main |
(character) main title for the plot. |
extra_info |
(logical) when results are from more than one model, it adds information about the number of models using each predictor and the mean contribution found. |
... |
additional arguments passed to barplot or boxplot. |
No return value, called for side effects (a barplot or boxplot depending on the number of models considered..
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.